Admin control-plane library for actrix nodes.
This crate is the canonical implementation for node-side control-plane behavior (node_admin gRPC API server).
Re-exports
pub use auth::AuthService;pub use auth::CredentialPayload;pub use error::AdminError;pub use error::Result as AdminResult;pub use realm::realm_to_proto;pub use service::AdminApiService;pub use service::ConfigFileContent;pub use service::HealthInfo;pub use service::KeyInfo;pub use service::KsCleanupResult;pub use service::KsKeysResult;pub use service::PlatformDetail;pub use service::RealmSecretRotationResult;pub use service::ServiceDetail;
Modules
- auth
- error
- Error types for admin
- metrics
- System metrics collection using pwrzv
- nonce_
auth - Nonce-auth integration module
- realm
- service
Structs
- Control
Service Client - Control
Service Server - Create
Realm Request - Create
Realm Response - Delete
Config Override Request - Delete
Config Override Response - Delete
Realm Request - Delete
Realm Response - Directive
- GetConfig
Request - GetConfig
Response - GetNode
Info Request - GetNode
Info Response - GetRealm
Request - GetRealm
Response - Health
Check Request - Health
Check Response - List
Config Overrides Request - List
Config Overrides Response - List
Realms Request - List
Realms Response - Node
Admin Service Client - Node
Admin Service Server - Nonce
Credential - NonceCredential is used for authentication in all RPC requests Compatible with nonce-auth library’s NonceCredential structure
- Proto
Config Override Entry - Realm
Info - Register
Node Request - Register
Node Response - Report
Request - Report
Response - Service
Advertisement - Service
Status - SetConfig
Override Request - SetConfig
Override Response - Shutdown
Request - Shutdown
Response - System
Metrics - Update
Config Request - Update
Config Response - Update
Realm Request - Update
Realm Response
Enums
Traits
- Control
Service - Generated trait containing gRPC methods that should be implemented for use with ControlServiceServer.
- Node
Admin Service - Generated trait containing gRPC methods that should be implemented for use with NodeAdminServiceServer.