pub struct UpdateConfigReq {
pub pointer: String,
pub new_value: Value,
}Fields
pointer: StringJSON Pointer (see RFC6901) to the part of the configuration that is to be changed
Example: “/transcryptor/enc_key”
new_value: ValueTrait Implementations
Sourceimpl Clone for UpdateConfigReq
impl Clone for UpdateConfigReq
Sourcefn clone(&self) -> UpdateConfigReq
fn clone(&self) -> UpdateConfigReq
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateConfigReq
impl Debug for UpdateConfigReq
Sourceimpl<'de> Deserialize<'de> for UpdateConfigReq
impl<'de> Deserialize<'de> for UpdateConfigReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for UpdateConfigReq
impl Serialize for UpdateConfigReq
Sourceimpl Signable for UpdateConfigReq
impl Signable for UpdateConfigReq
const CODE: MessageCode = crate::api::MessageCode::AdminUpdateConfigReq
Sourceconst CONSTELLATION_BOUND: bool = false
const CONSTELLATION_BOUND: bool = false
Include a
CONSTELLATION_CLAIM in the Signed message of this type, binding the
signed message to the current Constellation.Auto Trait Implementations
impl Freeze for UpdateConfigReq
impl RefUnwindSafe for UpdateConfigReq
impl Send for UpdateConfigReq
impl Sync for UpdateConfigReq
impl Unpin for UpdateConfigReq
impl UnsafeUnpin for UpdateConfigReq
impl UnwindSafe for UpdateConfigReq