pub struct UpdateConfigEP {}Expand description
Changes the crate::servers::Config in memory, and restarts the server service. The configuration file remains unchanged, so when the binary restarts, the changes are lost. This endpoint is used for testing, and can also be useful for debugging.
The request is verified using the crate::servers::config::ServerConfig::admin_key.